@@ -1,4 +1,4 @@
-#' Conditon based dropping of columns with missing values
+#' Condition based dropping of columns with missing values
 #' @description "drop_na_if" provides a simple way to drop columns with missing values if
 #' they meet certain criteria/conditions.
 #' @param df A data.frame object
@@ -17,48 +17,32 @@
 #' head(drop_na_if(airquality, sign="gteq",percent_na = 4, keep_columns = "Ozone"))
 #' @export
 
-drop_na_if <- function(df, sign="gteq",percent_na= 50,
-                       keep_columns = NULL,
-                       ...){
+drop_na_if <- function(df, sign="gteq",percent_na= 50,keep_columns=NULL,...){
   UseMethod("drop_na_if")
 }
 
 #' @export
 
-drop_na_if.data.frame <- function(df,sign="gteq",percent_na = 50,
-                                  keep_columns  = NULL,
-                                  ...){
+drop_na_if.data.frame <- function(df,sign="gteq",percent_na=50,keep_columns  = NULL, ...){
 
-available_options <- c("gteq","lteq","gt","lt","eq")
 
-if(! sign %in% available_options ) {
-  stop(paste(paste(c("I was expecting one of ",available_options),collapse=" "),
-             "not",
-              sign))
-}
+# get percent missing
+missing_percents <- percent_missing(df,...)
+# Drop as required
 
-# get percent missingness
-
-missing_percents <-  percent_missing(df,...)
-
-to_drop<- switch(sign,
-       gteq = which(missing_percents >=percent_na),
-         lteq =  which(missing_percents <=percent_na),
-           gt =  which(missing_percents >percent_na),
-              lt = which(missing_percents <percent_na),
-                eq = which(missing_percents == percent_na))
+to_drop <- switches(target_value=missing_percents,sign,percent_na)
 
 if(!is.null(keep_columns)){
-  if(!all(keep_columns %in% names(df))){
-    stop("All columns to keep should exist in the data set.")
-  }
-  keep_columns <- which(names(df) %in% keep_columns)
+
+check_column_existence(df,target_columns = keep_columns, unique_name = "to keep")
+
+keep_columns <- which(names(df) %in% keep_columns)
 
 }
 to_drop <- setdiff(to_drop, keep_columns)
-if(length(to_drop) ==0){
-  return(df)
-}
+
+if(length(to_drop) ==0) return(df)
+
 df[-to_drop]
 }
 
